@@ -10,7 +10,7 @@ Created on 04 Mar 2021
 """
 
 from datetime import datetime
-from pynmeagps.nmeatypes_core import LA, LN
+from pynmeagps.nmeatypes_core import NMEA_MSGIDS, LA, LN
 import pynmeagps.exceptions as nme
 
 KNOTSCONV = {"MS": 0.5144447324, "FS": 1.68781084, "MPH": 1.15078, "KMPH": 1.852001}
@@ -44,12 +44,12 @@ def get_parts(message: object) -> tuple:
         content, cksum = message.strip("$\r\n").split("*", 1)
         hdr, payload = content.split(",", 1)
         payload = payload.split(",")
-        if hdr[0:1] == "G":  # standard
+        if hdr[0:1] == "P":  # proprietary
+            talker = "P"
+            msgid = hdr[1:]
+        else:  # standard
             talker = hdr[0:2]
             msgid = hdr[2:]
-        else:
-            talker = ""
-            msgid = hdr
         return talker, msgid, payload, cksum
     except Exception as err:
         raise nme.NMEAMessageError(f"Badly formed message {message}") from err
@@ -183,7 +183,6 @@ def time2utc(times: str) -> datetime.time:
 
     if times == "":
         return ""
-    # TODO check this is correct
     utc = datetime.strptime(times, "%H%M%S.%f")
     return utc.time()
 
@@ -290,3 +289,17 @@ def knots2spd(knots: float, unit: str = "MS") -> float:
         raise TypeError(
             f"Invalid knots value {knots} - must be float or integer."
         ) from err
+
+
+def msgdesc(msgID: str) -> str:
+    """
+    Return descriptive string for NMEA msgId.
+
+    :param msgID str: message ID e.g. 'GGA'
+    :return: description of message
+    :rtype: str
+
+    """
+    # pylint: disable=invalid-name
+
+    return NMEA_MSGIDS.get(msgID, f"Unknown msgID {msgID}")
