@@ -41,13 +41,13 @@ NMEA_PAYLOADS_POLL = {
     # *********************************************
     # PROPRIETARY MESSAGES
     # *********************************************
-    "PUBX00": {
+    "UBX00": {
         "msgId": IN,  # 00
     },
-    "PUBX03": {
+    "UBX03": {
         "msgId": IN,  # 03
     },
-    "PUBX04": {
+    "UBX04": {
         "msgId": IN,  # 04
     },
 }
